@@ -534,6 +534,18 @@ class FlowLiveUpdaterOptions:
     print_stats: bool = False
 
 
+class FlowUpdaterStatusUpdates(NamedTuple):
+    """
+    Status updates for a flow updater.
+    """
+
+    # Sources that are still active, i.e. not stopped processing.
+    active_sources: list[str]
+
+    # Sources with updates since last time.
+    updated_sources: list[str]
+
+
 class FlowLiveUpdater:
     """
     A live updater for a flow.
@@ -587,7 +599,26 @@ class FlowLiveUpdater:
         """
         Wait for the live updater to finish. Async version.
         """
-        await self._get_engine_live_updater().wait()
+        await self._get_engine_live_updater().wait_async()
+
+    def next_status_updates(self) -> FlowUpdaterStatusUpdates:
+        """
+        Get the next status updates.
+
+        It blocks until there's a new status updates, including the processing finishes for a bunch of source updates,
+        and live updater stops (aborted, or no more sources to process).
+        """
+        return execution_context.run(self.next_status_updates_async())
+
+    async def next_status_updates_async(self) -> FlowUpdaterStatusUpdates:
+        """
+        Get the next status updates. Async version.
+        """
+        updates = await self._get_engine_live_updater().next_status_updates_async()
+        return FlowUpdaterStatusUpdates(
+            active_sources=updates.active_sources,
+            updated_sources=updates.updated_sources,
+        )
 
     def abort(self) -> None:
         """
@@ -624,7 +655,7 @@ class Flow:
 
     _name: str
     _full_name: str
-    _lazy_engine_flow: Callable[[], _engine.Flow]
+    _lazy_engine_flow: Callable[[], _engine.Flow] | None
 
     def __init__(
         self, name: str, full_name: str, engine_flow_creator: Callable[[], _engine.Flow]
@@ -664,18 +695,18 @@ class Flow:
         return tree
 
     def _get_spec(self, verbose: bool = False) -> _engine.RenderedSpec:
-        return self._lazy_engine_flow().get_spec(
+        return self.internal_flow().get_spec(
             output_mode="verbose" if verbose else "concise"
         )
 
     def _get_schema(self) -> list[tuple[str, str, str]]:
-        return cast(list[tuple[str, str, str]], self._lazy_engine_flow().get_schema())
+        return cast(list[tuple[str, str, str]], self.internal_flow().get_schema())
 
     def __str__(self) -> str:
         return str(self._get_spec())
 
     def __repr__(self) -> str:
-        return repr(self._lazy_engine_flow())
+        return repr(self.internal_flow())
 
     @property
     def name(self) -> str:
@@ -715,12 +746,14 @@ class Flow:
         """
         Evaluate the flow and dump flow outputs to files.
         """
-        return self._lazy_engine_flow().evaluate_and_dump(dump_engine_object(options))
+        return self.internal_flow().evaluate_and_dump(dump_engine_object(options))
 
     def internal_flow(self) -> _engine.Flow:
         """
         Get the engine flow.
         """
+        if self._lazy_engine_flow is None:
+            raise RuntimeError(f"Flow {self.full_name} is already removed")
         return self._lazy_engine_flow()
 
     async def internal_flow_async(self) -> _engine.Flow:
@@ -731,13 +764,13 @@ class Flow:
 
     def setup(self, report_to_stdout: bool = False) -> None:
         """
-        Setup the flow.
+        Setup persistent backends of the flow.
         """
         execution_context.run(self.setup_async(report_to_stdout=report_to_stdout))
 
     async def setup_async(self, report_to_stdout: bool = False) -> None:
         """
-        Setup the flow. The async version.
+        Setup persistent backends of the flow. The async version.
         """
         await make_setup_bundle([self]).describe_and_apply_async(
             report_to_stdout=report_to_stdout
@@ -745,13 +778,18 @@ class Flow:
 
     def drop(self, report_to_stdout: bool = False) -> None:
         """
-        Drop the flow.
+        Drop persistent backends of the flow.
+
+        The current instance is still valid after it's called.
+        For example, you can still call `setup()` after it, to setup the persistent backends again.
+
+        Call `cocoindex.remove_flow()` if you want to remove the flow from the current process.
         """
         execution_context.run(self.drop_async(report_to_stdout=report_to_stdout))
 
     async def drop_async(self, report_to_stdout: bool = False) -> None:
         """
-        Drop the flow. The async version.
+        Drop persistent backends of the flow. The async version.
         """
         await make_drop_bundle([self]).describe_and_apply_async(
             report_to_stdout=report_to_stdout
@@ -805,6 +843,19 @@ def add_flow_def(name: str, fl_def: Callable[[FlowBuilder, DataScope], None]) ->
     return fl
 
 
+def remove_flow(fl: Flow) -> None:
+    """
+    Remove a flow from the current process to free up resources.
+    After it's called, methods of the flow should no longer be called.
+
+    This will NOT touch the persistent backends of the flow.
+    """
+    _engine.remove_flow_context(fl.full_name)
+    fl._lazy_engine_flow = None  # pylint: disable=protected-access
+    with _flows_lock:
+        del _flows[fl.name]
+
+
 def flow_def(
     name: str | None = None,
 ) -> Callable[[Callable[[FlowBuilder, DataScope], None]], Flow]:
@@ -859,10 +910,7 @@ def update_all_flows(
     """
     Update all flows.
     """
-    return cast(
-        dict[str, _engine.IndexUpdateInfo],
-        execution_context.run(update_all_flows_async(options)),
-    )
+    return execution_context.run(update_all_flows_async(options))
 
 
 async def update_all_flows_async(
@@ -938,7 +986,7 @@ class TransformFlow(Generic[T]):
     def _flow_info(self) -> TransformFlowInfo:
         if self._lazy_flow_info is not None:
             return self._lazy_flow_info
-        return cast(TransformFlowInfo, execution_context.run(self._flow_info_async()))
+        return execution_context.run(self._flow_info_async())
 
     async def _flow_info_async(self) -> TransformFlowInfo:
         if self._lazy_flow_info is not None:
@@ -1017,7 +1065,7 @@ class TransformFlow(Generic[T]):
         """
         Evaluate the transform flow.
         """
-        return cast(T, execution_context.run(self.eval_async(*args, **kwargs)))
+        return execution_context.run(self.eval_async(*args, **kwargs))
 
     async def eval_async(self, *args: Any, **kwargs: Any) -> T:
         """
