@@ -3,7 +3,6 @@ use log::{error, trace};
 use regex::{Matches, Regex};
 use std::collections::HashSet;
 use std::sync::LazyLock;
-use std::usize;
 use std::{collections::HashMap, sync::Arc};
 use unicase::UniCase;
 
@@ -389,7 +388,7 @@ fn line_break_level(c: &str) -> LineBreakLevel {
     while let Some(c) = iter.next() {
         if c == '\n' || c == '\r' {
             lb_level = LineBreakLevel::Newline;
-            while let Some(c2) = iter.next() {
+            for c2 in iter.by_ref() {
                 if c2 == '\n' || c2 == '\r' {
                     if c == c2 {
                         return LineBreakLevel::DoubleNewline;
@@ -568,7 +567,8 @@ impl<'t, 's: 't> RecursiveChunker<'s> {
                 next_regexp_sep_id,
             } => {
                 if next_regexp_sep_id >= lang_config.separator_regex.len() {
-                    Ok(atom_collector.collect(chunk.range))
+                    atom_collector.collect(chunk.range);
+                    Ok(())
                 } else {
                     self.collect_atom_chunks_from_iter(
                         TextChunksIter::new(lang_config, &chunk, next_regexp_sep_id),
@@ -619,7 +619,7 @@ impl<'t, 's: 't> RecursiveChunker<'s> {
             }
         };
 
-        for (i, chunk) in (&atom_chunks[0..atom_chunks.len() - 1]).iter().enumerate() {
+        for (i, chunk) in atom_chunks[0..atom_chunks.len() - 1].iter().enumerate() {
             let mut min_cost = usize::MAX;
             let mut arg_min_start_idx: usize = 0;
             let mut arg_min_prev_plan_idx: usize = 0;
@@ -1031,6 +1031,7 @@ pub fn register(registry: &mut ExecutorFactoryRegistry) -> Result<()> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ops::functions::test_utils::{build_arg_schema, test_flow_function};
 
     // Helper function to assert chunk text and its consistency with the range within the original text.
     fn assert_chunk_text_consistency(
@@ -1046,14 +1047,12 @@ mod tests {
         // Assert that the expected text matches the text provided in the chunk.
         assert_eq!(
             actual_chunk.text, expected_text,
-            "Provided chunk text mismatch - {}",
-            context
+            "Provided chunk text mismatch - {context}"
         );
         // Assert that the expected text also matches the text extracted using the chunk's range.
         assert_eq!(
             extracted_text, expected_text,
-            "Range inconsistency: extracted text mismatch - {}",
-            context
+            "Range inconsistency: extracted text mismatch - {context}"
         );
     }
 
@@ -1072,6 +1071,65 @@ mod tests {
         }
     }
 
+    #[tokio::test]
+    async fn test_split_recursively() {
+        let spec = Spec {
+            custom_languages: vec![],
+        };
+        let factory = Arc::new(Factory);
+        let text_content = "Linea 1.\nLinea 2.\n\nLinea 3.";
+
+        let input_args_values = vec![
+            text_content.to_string().into(),
+            (15i64).into(),
+            (5i64).into(),
+            (0i64).into(),
+            Value::Null,
+        ];
+
+        let input_arg_schemas = vec![
+            build_arg_schema("text", BasicValueType::Str),
+            build_arg_schema("chunk_size", BasicValueType::Int64),
+            build_arg_schema("min_chunk_size", BasicValueType::Int64),
+            build_arg_schema("chunk_overlap", BasicValueType::Int64),
+            build_arg_schema("language", BasicValueType::Str),
+        ];
+
+        let result = test_flow_function(factory, spec, input_arg_schemas, input_args_values).await;
+
+        assert!(
+            result.is_ok(),
+            "test_flow_function failed: {:?}",
+            result.err()
+        );
+        let value = result.unwrap();
+
+        match value {
+            Value::KTable(table) => {
+                let expected_chunks = vec![
+                    (RangeValue::new(0, 8), "Linea 1."),
+                    (RangeValue::new(9, 17), "Linea 2."),
+                    (RangeValue::new(19, 27), "Linea 3."),
+                ];
+
+                for (range, expected_text) in expected_chunks {
+                    let key: KeyValue = range.into();
+                    match table.get(&key) {
+                        Some(scope_value_ref) => {
+                            let chunk_text =
+                                scope_value_ref.0.fields[0].as_str().unwrap_or_else(|_| {
+                                    panic!("Chunk text not a string for key {key:?}")
+                                });
+                            assert_eq!(**chunk_text, *expected_text);
+                        }
+                        None => panic!("Expected row value for key {key:?}, not found"),
+                    }
+                }
+            }
+            other => panic!("Expected Value::KTable, got {other:?}"),
+        }
+    }
+
     #[test]
     fn test_translate_bytes_to_chars_simple() {
         let text = "abc😄def";
@@ -1179,6 +1237,7 @@ mod tests {
         assert_chunk_text_consistency(text2, &chunks2[0], "A very very long", "Test 2, Chunk 0");
         assert!(chunks2[0].text.len() <= 20);
     }
+
     #[test]
     fn test_basic_split_with_overlap() {
         let text = "This is a test text that is a bit longer to see how the overlap works.";
@@ -1198,6 +1257,7 @@ mod tests {
             assert!(chunks[0].text.len() <= 25);
         }
     }
+
     #[test]
     fn test_split_trims_whitespace() {
         let text = "  \n First chunk. \n\n  Second chunk with spaces at the end.   \n";
